@@ -26,6 +26,7 @@
 #endif
 
 #ifdef __MINGW32__
+#include <stdio.h>
 extern HANDLE io_comport;
 #endif
 array io_fds;
@@ -52,6 +53,7 @@ int io_fd(int64 d) {
     return 0;	/* file descriptor not open */
 #endif
   if (!(e=array_allocate(&io_fds,sizeof(io_entry),d))) return 0;
+  if (e->inuse) return 1;
   byte_zero(e,sizeof(io_entry));
   e->inuse=1;
 #ifdef __MINGW32__
@@ -88,6 +90,17 @@ int io_fd(int64 d) {
           sigprocmask(SIG_BLOCK,&io_ss,0)==0)
 	io_waitmode=_SIGIO;
     }
+#endif
+#ifdef __MINGW32__
+    io_comport=CreateIoCompletionPort(INVALID_HANDLE_VALUE,NULL,0,0);
+    if (io_comport) {
+      io_waitmode=COMPLETIONPORT;
+      fprintf(stderr,"Initialized completion port: %p\n",io_comport);
+    } else {
+      fprintf(stderr,"ARGH!  Could not init completion port!\n");
+      errno=EINVAL;
+      return 0;
+    }
 #endif
   }
 #if defined(HAVE_SIGIO)
@@ -99,6 +112,17 @@ int io_fd(int64 d) {
 #endif
     fcntl(d,F_SETFL,fcntl(d,F_GETFL)|O_NONBLOCK|O_ASYNC);
   }
+#endif
+#ifdef __MINGW32__
+  if (io_comport) {
+    fprintf(stderr,"Queueing %p at completion port %p...",d,io_comport);
+    if (CreateIoCompletionPort((HANDLE)d,io_comport,(ULONG_PTR)d,0)==0) {
+      fprintf(stderr," failed!\n");
+      errno=EBADF;
+      return 0;
+    }
+    fprintf(stderr," OK!\n");
+  }
 #endif
   return 1;
 }
