@@ -1,4 +1,5 @@
 #include <stdlib.h>
+#include <sys/mman.h>
 #include "byte.h"
 #include "iob_internal.h"
 
@@ -7,10 +8,8 @@ void iob_reset(io_batch* b) {
   iob_entry* x=array_start(&b->b);
   l=array_length(&b->b,sizeof(iob_entry));
   for (i=0; i<l; ++i) {
-    if (x[i].type==FROMBUF_FREE)
-      free((char*)x[i].buf);
-    if (x[i].type==FROMFILE_CLOSE)
-      io_close(x[i].fd);
+    if (x[i].cleanup)
+      x[i].cleanup(x+i);
   }
   array_reset(&b->b);
   byte_zero(b,sizeof(*b));
