@@ -1,5 +1,6 @@
 #include <sys/types.h>
 #ifndef __MINGW32__
+#include <unistd.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #endif
@@ -7,6 +8,7 @@
 #include <errno.h>
 #include "haveip6.h"
 #include "socket.h"
+#include "ndelay.h"
 
 #ifndef EAFNOSUPPORT
 #define EAFNOSUPPORT EINVAL
@@ -41,6 +43,7 @@ compat:
     winsock2errno(setsockopt(s,IPPROTO_IPV6,IPV6_V6ONLY,(void*)&zero,sizeof(zero)));
   }
 #endif
+  if (ndelay_on(s) == -1) { close(s); return -1; }
   return s;
 #else
   return socket_udp();
