@@ -67,7 +67,7 @@ void stralloc_zero(stralloc* sa);
 int stralloc_catm_internal(stralloc* sa,...);
 
 #define stralloc_catm(sa,...) stralloc_catm_internal(sa,__VA_ARGS__,(char*)0)
-#define stralloc_copym(sa,...) (stralloc_zero(sa) && stralloc_catm_internal(sa,__VA_ARGS__,(char*)0))
+#define stralloc_copym(sa,...) (stralloc_zero(sa), stralloc_catm_internal(sa,__VA_ARGS__,(char*)0))
 
 /* stralloc_cat is analogous to stralloc_copy */
 int stralloc_cat(stralloc* sa,stralloc* in);
