@@ -7,8 +7,8 @@
  * not enough to hold len bytes, stralloc_ready allocates at least len
  * bytes of space, copies the old string into the new space, frees the
  * old space, and returns 1. Note that this changes sa.s. */
-int stralloc_ready(stralloc *sa,unsigned long int len) {
-  register int wanted=len+(len>>3)+30; /* heuristic from djb */
+int stralloc_ready(stralloc *sa,size_t len) {
+  register size_t wanted=len+(len>>3)+30; /* heuristic from djb */
   if (!sa->s || sa->a<len) {
     register char* tmp;
     if (!(tmp=realloc(sa->s,wanted)))
