@@ -3,9 +3,9 @@
 #include "haveinline.h"
 #include "str.h"
 
-unsigned long fmt_quotedprintable2(char* dest,const char* src,unsigned long len,const char* escapeme) {
+size_t fmt_quotedprintable2(char* dest,const char* src,size_t len,const char* escapeme) {
   register const unsigned char* s=(const unsigned char*) src;
-  unsigned long written=0,i;
+  size_t written=0,i;
   for (i=0; i<len; ++i) {
     if (s[i]&0x80 || s[i]<' ' || s[i]=='=' || escapeme[str_chr(escapeme,s[i])]==s[i]) {
       if (dest) {
@@ -17,10 +17,12 @@ unsigned long fmt_quotedprintable2(char* dest,const char* src,unsigned long len,
     } else {
       if (dest) dest[written]=s[i]; ++written;
     }
+    /* in case someone gives us malicious input */
+    if (written>((size_t)-1)/2) return (size_t)-1;
   }
   return written;
 }
 
-unsigned long fmt_quotedprintable(char* dest,const char* src,unsigned long len) {
+size_t fmt_quotedprintable(char* dest,const char* src,size_t len) {
   return fmt_quotedprintable2(dest,src,len,"");
 }
