@@ -6,7 +6,7 @@
 typedef uint16_t uint16;
 typedef int16_t int16;
 
-#if defined(__i386__) && !defined(NO_UINT16_MACROS)
+#if (defined(__i386__) || defined(__x86_64__)) && !defined(NO_UINT16_MACROS)
 #define uint16_pack(out,in) (*(uint16*)(out)=(in))
 #define uint16_unpack(in,out) (*(out)=*(uint16*)(in))
 #define uint16_read(in) (*(uint16*)(in))
